==> erniebot-0.0.1-py3-none-any.whl: erniebot/resources/embedding.py <==
# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import (Any, ClassVar, Dict, Optional, Tuple)

import erniebot.errors as errors
from erniebot.api_types import APIType
from erniebot.types import (ParamsType, HeadersType, FilesType, ResponseT)
from .abc import Creatable
from .resource import EBResource


class Embedding(EBResource, Creatable):
    """Get the embeddings of a given text input."""

    _PREFIX: ClassVar[str] = 'embeddings'
    _MODEL_INFO_DICT: ClassVar[Dict[APIType, Dict[str, Any]]] = {
        APIType.QIANFAN: {
            'ernie-text-embedding': {
                'suffix': 'embedding-v1'
            }
        }
    }

    def _prepare_create(self, kwargs: Dict[str, Any]) -> Tuple[
        str,
        Optional[ParamsType],
        Optional[HeadersType],
        Optional[FilesType],
        bool,
        Optional[float]]:      # yapf: disable
        def _set_val_if_key_exists(src: dict, dst: dict, key: str) -> None:
            if key in src:
                dst[key] = src[key]

        VALID_KEYS = {'model', 'input', 'headers', 'stream', 'request_timeout'}

        invalid_keys = kwargs.keys() - VALID_KEYS

        if len(invalid_keys) > 0:
            raise errors.InvalidArgumentError(
                f"Invalid keys found in `kwargs`: {list(invalid_keys)}")

        # model
        if 'model' not in kwargs:
            raise errors.ArgumentNotFoundError("`model` is not found.")
        model = kwargs['model']

        # input
        if 'input' not in kwargs:
            raise errors.ArgumentNotFoundError("`input` is not found.")
        input = kwargs['input']

        # url
        if self.api_type in self._MODEL_INFO_DICT:
            model_info_dict = self._MODEL_INFO_DICT[self.api_type]
            if model not in model_info_dict:
                raise errors.InvalidArgumentError(
                    f"{repr(model)} is not a supported model.")
            url = f"/{self._PREFIX}/{model_info_dict[model]['suffix']}"
        else:
            raise errors.UnsupportedAPITypeError

        # params
        params = {}
        params['input'] = input
        _set_val_if_key_exists(kwargs, params, 'input')

        # headers
        headers = kwargs.get('headers', None)

        # files
        files = None

        # stream
        stream = kwargs.get('stream', False)

        # request_timeout
        request_timeout = kwargs.get('request_timeout', None)

        return url, params, headers, files, stream, request_timeout

    def _post_process_create(self, resp: ResponseT) -> ResponseT:
        return resp

==> erniebot-0.0.2-py3-none-any.whl: erniebot/resources/embedding.py <==
# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import (Any, ClassVar, Dict, Optional, Tuple)

import erniebot.errors as errors
from erniebot.api_types import APIType
from erniebot.types import (ParamsType, HeadersType, FilesType, ResponseT)
from .abc import Creatable
from .resource import EBResource


class Embedding(EBResource, Creatable):
    """Get the embeddings of a given text input."""

    _PREFIX: ClassVar[str] = 'embeddings'
    _MODEL_INFO_DICT: ClassVar[Dict[APIType, Dict[str, Any]]] = {
        APIType.QIANFAN: {
            'ernie-text-embedding': {
                'suffix': 'embedding-v1'
            }
        }
    }

    def _prepare_create(self,
                        kwargs: Dict[str, Any]) -> Tuple[str,
                                                         Optional[ParamsType],
                                                         Optional[HeadersType],
                                                         Optional[FilesType],
                                                         bool,
                                                         Optional[float],
                                                         ]:
        def _set_val_if_key_exists(src: dict, dst: dict, key: str) -> None:
            if key in src:
                dst[key] = src[key]

        VALID_KEYS = {'model', 'input', 'headers', 'stream', 'request_timeout'}

        invalid_keys = kwargs.keys() - VALID_KEYS

        if len(invalid_keys) > 0:
            raise errors.InvalidArgumentError(
                f"Invalid keys found in `kwargs`: {list(invalid_keys)}")

        # model
        if 'model' not in kwargs:
            raise errors.ArgumentNotFoundError("`model` is not found.")
        model = kwargs['model']

        # input
        if 'input' not in kwargs:
            raise errors.ArgumentNotFoundError("`input` is not found.")
        input = kwargs['input']

        # url
        if self.api_type in self._MODEL_INFO_DICT:
            model_info_dict = self._MODEL_INFO_DICT[self.api_type]
            if model not in model_info_dict:
                raise errors.InvalidArgumentError(
                    f"{repr(model)} is not a supported model.")
            url = f"/{self._PREFIX}/{model_info_dict[model]['suffix']}"
        else:
            raise errors.UnsupportedAPITypeError

        # params
        params = {}
        params['input'] = input
        _set_val_if_key_exists(kwargs, params, 'input')

        # headers
        headers = kwargs.get('headers', None)

        # files
        files = None

        # stream
        stream = kwargs.get('stream', False)

        # request_timeout
        request_timeout = kwargs.get('request_timeout', None)

        return url, params, headers, files, stream, request_timeout

    def _post_process_create(self, resp: ResponseT) -> ResponseT:
        return resp
